@@ -334,8 +334,8 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
     @testing.combinations(
         (
             lambda: select(literal("x"), literal("y")),
-            "SELECT [POSTCOMPILE_param_1] AS anon_1, "
-            "[POSTCOMPILE_param_2] AS anon_2",
+            "SELECT __[POSTCOMPILE_param_1] AS anon_1, "
+            "__[POSTCOMPILE_param_2] AS anon_2",
             {
                 "check_literal_execute": {"param_1": "x", "param_2": "y"},
                 "check_post_param": {},
@@ -344,7 +344,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
         (
             lambda t: select(t).where(t.c.foo.in_(["x", "y", "z"])),
             "SELECT sometable.foo FROM sometable WHERE sometable.foo "
-            "IN ([POSTCOMPILE_foo_1])",
+            "IN (__[POSTCOMPILE_foo_1])",
             {
                 "check_literal_execute": {"foo_1": ["x", "y", "z"]},
                 "check_post_param": {},
@@ -436,7 +436,8 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
         crit = q.c.myid == table1.c.myid
         self.assert_compile(
             select("*").where(crit),
-            "SELECT * FROM (SELECT TOP [POSTCOMPILE_param_1] mytable.myid AS "
+            "SELECT * FROM (SELECT TOP __[POSTCOMPILE_param_1] "
+            "mytable.myid AS "
             "myid FROM mytable ORDER BY mytable.myid) AS foo, mytable WHERE "
             "foo.myid = mytable.myid",
         )
@@ -810,10 +811,10 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
         self.assert_compile(
             u,
             "SELECT t1.col3 AS col3, t1.col4 AS col4 "
-            "FROM t1 WHERE t1.col2 IN ([POSTCOMPILE_col2_1]) "
+            "FROM t1 WHERE t1.col2 IN (__[POSTCOMPILE_col2_1]) "
             "UNION SELECT t2.col3 AS col3, "
             "t2.col4 AS col4 FROM t2 WHERE t2.col2 IN "
-            "([POSTCOMPILE_col2_2]) ORDER BY col3, col4",
+            "(__[POSTCOMPILE_col2_2]) ORDER BY col3, col4",
             checkparams={
                 "col2_1": ["t1col2r1", "t1col2r2"],
                 "col2_2": ["t2col2r2", "t2col2r3"],
@@ -823,9 +824,9 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             u.alias("bar").select(),
             "SELECT bar.col3, bar.col4 FROM (SELECT "
             "t1.col3 AS col3, t1.col4 AS col4 FROM t1 "
-            "WHERE t1.col2 IN ([POSTCOMPILE_col2_1]) UNION "
+            "WHERE t1.col2 IN (__[POSTCOMPILE_col2_1]) UNION "
             "SELECT t2.col3 AS col3, t2.col4 AS col4 "
-            "FROM t2 WHERE t2.col2 IN ([POSTCOMPILE_col2_2])) AS bar",
+            "FROM t2 WHERE t2.col2 IN (__[POSTCOMPILE_col2_2])) AS bar",
             checkparams={
                 "col2_1": ["t1col2r1", "t1col2r2"],
                 "col2_2": ["t2col2r2", "t2col2r3"],
@@ -972,7 +973,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
 
         self.assert_compile(
             s,
-            "SELECT TOP [POSTCOMPILE_param_1] t.x, t.y FROM t "
+            "SELECT TOP __[POSTCOMPILE_param_1] t.x, t.y FROM t "
             "WHERE t.x = :x_1 ORDER BY t.y",
             checkparams={"x_1": 5, "param_1": 10},
         )
@@ -1000,7 +1001,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
 
         self.assert_compile(
             s,
-            "SELECT TOP [POSTCOMPILE_param_1] t.x, t.y FROM t "
+            "SELECT TOP __[POSTCOMPILE_param_1] t.x, t.y FROM t "
             "WHERE t.x = :x_1 ORDER BY t.y",
             checkparams={"x_1": 5, "param_1": 0},
         )
@@ -1201,7 +1202,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
         # of zero, so produces TOP 0
         self.assert_compile(
             s,
-            "SELECT TOP [POSTCOMPILE_param_1] t.x, t.y FROM t "
+            "SELECT TOP __[POSTCOMPILE_param_1] t.x, t.y FROM t "
             "WHERE t.x = :x_1 ORDER BY t.y",
             checkparams={"x_1": 5, "param_1": 0},
         )
@@ -1445,21 +1446,21 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             5,
             0,
             {"percent": True},
-            "TOP [POSTCOMPILE_param_1] PERCENT",
+            "TOP __[POSTCOMPILE_param_1] PERCENT",
             {"param_1": 5},
         ),
         (
             5,
             None,
             {"percent": True, "with_ties": True},
-            "TOP [POSTCOMPILE_param_1] PERCENT WITH TIES",
+            "TOP __[POSTCOMPILE_param_1] PERCENT WITH TIES",
             {"param_1": 5},
         ),
         (
             5,
             0,
             {"with_ties": True},
-            "TOP [POSTCOMPILE_param_1] WITH TIES",
+            "TOP __[POSTCOMPILE_param_1] WITH TIES",
             {"param_1": 5},
         ),
         (
@@ -1537,21 +1538,21 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             5,
             0,
             {"percent": True},
-            "TOP [POSTCOMPILE_param_1] PERCENT",
+            "TOP __[POSTCOMPILE_param_1] PERCENT",
             {"param_1": 5},
         ),
         (
             5,
             None,
             {"percent": True, "with_ties": True},
-            "TOP [POSTCOMPILE_param_1] PERCENT WITH TIES",
+            "TOP __[POSTCOMPILE_param_1] PERCENT WITH TIES",
             {"param_1": 5},
         ),
         (
             5,
             0,
             {"with_ties": True},
-            "TOP [POSTCOMPILE_param_1] WITH TIES",
+            "TOP __[POSTCOMPILE_param_1] WITH TIES",
             {"param_1": 5},
         ),
         (
