@@ -367,6 +367,49 @@ class URLTest(fixtures.TestBase):
             )
         eq_(u1, url.make_url("somedriver://user@hostname:52"))
 
+    def test_deprecated_constructor_all_args(self):
+        """test #7130"""
+        with testing.expect_deprecated(
+            r"Calling URL\(\) directly is deprecated and will be "
+            "disabled in a future release."
+        ):
+            u1 = url.URL(
+                "somedriver",
+                "user",
+                "secret",
+                "10.20.30.40",
+                1234,
+                "DB",
+                {"key": "value"},
+            )
+        eq_(
+            u1,
+            url.make_url(
+                "somedriver://user:secret@10.20.30.40:1234/DB?key=value"
+            ),
+        )
+
+    @testing.requires.python3
+    def test_arg_validation_all_seven_posn(self):
+        """test #7130"""
+        with testing.expect_deprecated(
+            r"Calling URL\(\) directly is deprecated and will be "
+            "disabled in a future release."
+        ):
+
+            assert_raises_message(
+                TypeError,
+                "drivername must be a string",
+                url.URL,
+                b"somedriver",
+                "user",
+                "secret",
+                "10.20.30.40",
+                1234,
+                "DB",
+                {"key": "value"},
+            )
+
     def test_deprecated_translate_connect_args_names(self):
         u = url.make_url("somedriver://user@hostname:52")
 
