@@ -1,21 +1,26 @@
 import random
-import types
 
+import sqlalchemy as sa
+from sqlalchemy import Column
 from sqlalchemy import func
 from sqlalchemy import inspect
+from sqlalchemy import Integer
 from sqlalchemy import null
 from sqlalchemy import select
+from sqlalchemy import Table
 from sqlalchemy import testing
 from sqlalchemy import text
 from sqlalchemy import true
+from sqlalchemy import update
 from sqlalchemy.orm import aliased
+from sqlalchemy.orm import Bundle
 from sqlalchemy.orm import defaultload
 from sqlalchemy.orm import defer
 from sqlalchemy.orm import join as orm_join
 from sqlalchemy.orm import joinedload
 from sqlalchemy.orm import lazyload
 from sqlalchemy.orm import Load
-from sqlalchemy.orm import mapper
+from sqlalchemy.orm import load_only
 from sqlalchemy.orm import Query
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm import selectinload
@@ -29,7 +34,7 @@ from sqlalchemy.sql.expression import case
 from sqlalchemy.sql.visitors import InternalTraversal
 from sqlalchemy.testing import AssertsCompiledSQL
 from sqlalchemy.testing import eq_
-from sqlalchemy.testing import mock
+from sqlalchemy.testing import fixtures
 from sqlalchemy.testing import ne_
 from sqlalchemy.testing.fixtures import fixture_session
 from test.orm import _fixtures
@@ -80,6 +85,33 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
             compare_values=True,
         )
 
+    def test_bundles_in_annotations(self):
+        User = self.classes.User
+
+        self._run_cache_key_fixture(
+            lambda: (
+                Bundle("mybundle", User.id).__clause_element__(),
+                Bundle("myotherbundle", User.id).__clause_element__(),
+                Bundle("mybundle", User.name).__clause_element__(),
+                Bundle("mybundle", User.id, User.name).__clause_element__(),
+            ),
+            compare_values=True,
+        )
+
+    def test_bundles_directly(self):
+        User = self.classes.User
+
+        self._run_cache_key_fixture(
+            lambda: (
+                Bundle("mybundle", User.id),
+                Bundle("mybundle", User.id).__clause_element__(),
+                Bundle("myotherbundle", User.id),
+                Bundle("mybundle", User.name),
+                Bundle("mybundle", User.id, User.name),
+            ),
+            compare_values=True,
+        )
+
     def test_query_expr(self):
         (User,) = self.classes("User")
 
@@ -190,11 +222,35 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
             compare_values=True,
         )
 
+    def test_unbound_sub_options(self):
+        """test #6869"""
+
+        User, Address, Keyword, Order, Item = self.classes(
+            "User", "Address", "Keyword", "Order", "Item"
+        )
+
+        self._run_cache_key_fixture(
+            lambda: (
+                joinedload(User.addresses).options(
+                    joinedload(Address.dingaling)
+                ),
+                joinedload(User.addresses).options(
+                    joinedload(Address.dingaling).options(load_only("name"))
+                ),
+                joinedload(User.orders).options(
+                    joinedload(Order.items).options(joinedload(Item.keywords))
+                ),
+            ),
+            compare_values=True,
+        )
+
     def test_bound_options(self):
         User, Address, Keyword, Order, Item = self.classes(
             "User", "Address", "Keyword", "Order", "Item"
         )
 
+        a1 = aliased(Address)
+
         self._run_cache_key_fixture(
             lambda: (
                 Load(User).joinedload(User.addresses),
@@ -207,10 +263,10 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
                     User.orders.and_(Order.description != "somename")
                 ),
                 Load(User).defer(User.id),
-                Load(User).subqueryload("addresses"),
-                Load(Address).defer("id"),
+                Load(User).subqueryload(User.addresses),
+                Load(Address).defer(Address.id),
                 Load(Address).defer("*"),
-                Load(aliased(Address)).defer("id"),
+                Load(a1).defer(a1.id),
                 Load(User).joinedload(User.addresses).defer(Address.id),
                 Load(User).joinedload(User.orders).joinedload(Order.items),
                 Load(User).joinedload(User.orders).subqueryload(Order.items),
@@ -222,33 +278,11 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
                 Load(User).defaultload(User.orders).defaultload(Order.items),
                 Load(User).defaultload(User.orders),
                 Load(Address).raiseload("*"),
-                Load(Address).raiseload("user"),
+                Load(Address).raiseload(Address.user),
             ),
             compare_values=True,
         )
 
-    def test_bound_options_equiv_on_strname(self):
-        """Bound loader options resolve on string name so test that the cache
-        key for the string version matches the resolved version.
-
-        """
-        User, Address, Keyword, Order, Item = self.classes(
-            "User", "Address", "Keyword", "Order", "Item"
-        )
-
-        for left, right in [
-            (Load(User).defer(User.id), Load(User).defer("id")),
-            (
-                Load(User).joinedload(User.addresses),
-                Load(User).joinedload("addresses"),
-            ),
-            (
-                Load(User).joinedload(User.orders).joinedload(Order.items),
-                Load(User).joinedload("orders").joinedload("items"),
-            ),
-        ]:
-            eq_(left._generate_cache_key(), right._generate_cache_key())
-
     def test_selects_w_orm_joins(self):
 
         User, Address, Keyword, Order, Item = self.classes(
@@ -299,16 +333,10 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
                 .join(User.orders),
                 fixture_session()
                 .query(User)
-                .join("addresses")
-                .join("dingalings", from_joinpoint=True),
-                fixture_session().query(User).join("addresses"),
-                fixture_session().query(User).join("orders"),
-                fixture_session().query(User).join("addresses").join("orders"),
+                .join(User.addresses)
+                .join(Address.dingaling),
                 fixture_session().query(User).join(Address, User.addresses),
-                fixture_session().query(User).join(a1, "addresses"),
-                fixture_session()
-                .query(User)
-                .join(a1, "addresses", aliased=True),
+                fixture_session().query(User).join(a1, User.addresses),
                 fixture_session().query(User).join(User.addresses.of_type(a1)),
             ),
             compare_values=True,
@@ -553,13 +581,6 @@ class PolyCacheKeyTest(CacheKeyFixture, _poly_fixtures._Polymorphic):
             "Person", "Manager", "Engineer", "Boss"
         )
 
-        def one():
-            return (
-                fixture_session()
-                .query(Person)
-                .with_polymorphic([Manager, Engineer])
-            )
-
         def two():
             wp = with_polymorphic(Person, [Manager, Engineer])
 
@@ -575,14 +596,6 @@ class PolyCacheKeyTest(CacheKeyFixture, _poly_fixtures._Polymorphic):
 
             return fixture_session().query(wp).filter(wp.name == "asdfo")
 
-        def four():
-            return (
-                fixture_session()
-                .query(Person)
-                .with_polymorphic([Manager, Engineer])
-                .filter(Person.name == "asdf")
-            )
-
         def five():
             subq = (
                 select(Person)
@@ -594,25 +607,8 @@ class PolyCacheKeyTest(CacheKeyFixture, _poly_fixtures._Polymorphic):
 
             return fixture_session().query(wp).filter(wp.name == "asdfo")
 
-        def six():
-            subq = (
-                select(Person)
-                .outerjoin(Manager)
-                .outerjoin(Engineer)
-                .subquery()
-            )
-
-            return (
-                fixture_session()
-                .query(Person)
-                .with_polymorphic([Manager, Engineer], subq)
-                .filter(Person.name == "asdfo")
-            )
-
         self._run_cache_key_fixture(
-            lambda: stmt_20(
-                one(), two(), three(), three_a(), four(), five(), six()
-            ),
+            lambda: stmt_20(two(), three(), three_a(), five()),
             compare_values=True,
         )
 
@@ -667,7 +663,7 @@ class RoundTripTest(QueryTest, AssertsCompiledSQL):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -677,7 +673,7 @@ class RoundTripTest(QueryTest, AssertsCompiledSQL):
             },
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             Address,
             addresses,
             properties={
@@ -796,18 +792,17 @@ class RoundTripTest(QueryTest, AssertsCompiledSQL):
             go()
 
     @testing.combinations(
-        (lazyload, 2, 6),
-        (joinedload, 1, 0),
-        (selectinload, 2, 5),
-        (subqueryload, 2, 0),
-        argnames="strat,expected_stmt_cache,expected_lambda_cache",
+        (lazyload, 2),
+        (joinedload, 1),
+        (selectinload, 2),
+        (subqueryload, 2),
+        argnames="strat,expected_stmt_cache",
     )
     def test_cache_key_loader_strategies(
         self,
         plain_fixture,
         strat,
         expected_stmt_cache,
-        expected_lambda_cache,
         connection,
     ):
         User, Address = plain_fixture
@@ -817,37 +812,94 @@ class RoundTripTest(QueryTest, AssertsCompiledSQL):
         connection = connection.execution_options(compiled_cache=cache)
         sess = Session(connection)
 
-        with mock.patch(
-            "sqlalchemy.orm.strategies.LazyLoader._lambda_cache", cache
-        ), mock.patch(
-            "sqlalchemy.orm.strategies.SelectInLoader._lambda_cache", cache
-        ):
+        def go():
+            stmt = (
+                select(User).where(User.id == 7).options(strat(User.addresses))
+            )
 
-            def go():
-                stmt = (
-                    select(User)
-                    .where(User.id == 7)
-                    .options(strat(User.addresses))
-                )
+            u1 = sess.execute(stmt).scalars().first()
+            eq_(u1.addresses, [Address(id=1)])
 
-                u1 = sess.execute(stmt).scalars().first()
-                eq_(u1.addresses, [Address(id=1)])
+        go()
 
+        lc = len(cache)
+
+        stmt_entries = [k for k in cache]
+
+        eq_(len(stmt_entries), expected_stmt_cache)
+
+        for i in range(3):
             go()
 
-            lc = len(cache)
+        eq_(len(cache), lc)
 
-            stmt_entries = [
-                k for k in cache if not isinstance(k[0], types.CodeType)
-            ]
-            lambda_entries = [
-                k for k in cache if isinstance(k[0], types.CodeType)
-            ]
 
-            eq_(len(stmt_entries), expected_stmt_cache)
-            eq_(len(lambda_entries), expected_lambda_cache)
+class CompositeTest(fixtures.MappedTest):
+    __dialect__ = "default"
 
-            for i in range(3):
-                go()
+    @classmethod
+    def define_tables(cls, metadata):
+        Table(
+            "edges",
+            metadata,
+            Column("id", Integer, primary_key=True),
+            Column("x1", Integer),
+            Column("y1", Integer),
+            Column("x2", Integer),
+            Column("y2", Integer),
+        )
 
-            eq_(len(cache), lc)
+    @classmethod
+    def setup_mappers(cls):
+        edges = cls.tables.edges
+
+        class Point(cls.Comparable):
+            def __init__(self, x, y):
+                self.x = x
+                self.y = y
+
+            def __composite_values__(self):
+                return [self.x, self.y]
+
+            __hash__ = None
+
+            def __eq__(self, other):
+                return (
+                    isinstance(other, Point)
+                    and other.x == self.x
+                    and other.y == self.y
+                )
+
+            def __ne__(self, other):
+                return not isinstance(other, Point) or not self.__eq__(other)
+
+        class Edge(cls.Comparable):
+            def __init__(self, *args):
+                if args:
+                    self.start, self.end = args
+
+        cls.mapper_registry.map_imperatively(
+            Edge,
+            edges,
+            properties={
+                "start": sa.orm.composite(Point, edges.c.x1, edges.c.y1),
+                "end": sa.orm.composite(Point, edges.c.x2, edges.c.y2),
+            },
+        )
+
+    def test_bulk_update_cache_key(self):
+        """test secondary issue located as part of #7209"""
+        Edge, Point = (self.classes.Edge, self.classes.Point)
+
+        stmt = (
+            update(Edge)
+            .filter(Edge.start == Point(14, 5))
+            .values({Edge.end: Point(16, 10)})
+        )
+        stmt2 = (
+            update(Edge)
+            .filter(Edge.start == Point(14, 5))
+            .values({Edge.end: Point(17, 8)})
+        )
+
+        eq_(stmt._generate_cache_key(), stmt2._generate_cache_key())
