@@ -16,7 +16,6 @@ from sqlalchemy.orm import exc as orm_exc
 from sqlalchemy.orm import joinedload
 from sqlalchemy.orm import lazyload
 from sqlalchemy.orm import make_transient_to_detached
-from sqlalchemy.orm import mapper
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm import Session
 from sqlalchemy.orm import strategies
@@ -43,15 +42,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
         assert len(u.addresses) == 1
         u.name = "foo"
         del u.addresses[0]
@@ -68,7 +67,9 @@ class ExpireTest(_fixtures.FixtureTest):
         u.name = "foo"
         sess.flush()
         # change the value in the DB
-        sess.execute(users.update(users.c.id == 7, values=dict(name="jack")))
+        sess.execute(
+            users.update().values(dict(name="jack")).where(users.c.id == 7)
+        )
         sess.expire(u)
         # object isn't refreshed yet, using dict to bypass trigger
         assert u.__dict__.get("name") != "jack"
@@ -88,13 +89,15 @@ class ExpireTest(_fixtures.FixtureTest):
         User, users = self.classes.User, self.tables.users
         Address, addresses = self.classes.Address, self.tables.addresses
 
-        mapper(User, users)
-        mapper(Address, addresses, properties={"user": relationship(User)})
+        self.mapper_registry.map_imperatively(User, users)
+        self.mapper_registry.map_imperatively(
+            Address, addresses, properties={"user": relationship(User)}
+        )
 
         s = fixture_session()
 
-        a1 = s.query(Address).get(2)
-        u1 = s.query(User).get(7)
+        a1 = s.get(Address, 2)
+        u1 = s.get(User, 7)
         a1.user = u1
 
         s.expire(a1, ["user_id"])
@@ -105,9 +108,9 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_persistence_check(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session()
-        u = s.query(User).get(7)
+        u = s.get(User, 7)
         s.expunge_all()
 
         assert_raises_message(
@@ -120,13 +123,13 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_get_refreshes(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session(autocommit=False)
-        u = s.query(User).get(10)
+        u = s.get(User, 10)
         s.expire_all()
 
         def go():
-            s.query(User).get(10)  # get() refreshes
+            s.get(User, 10)  # get() refreshes
 
         self.assert_sql_count(testing.db, go, 1)
 
@@ -136,31 +139,31 @@ class ExpireTest(_fixtures.FixtureTest):
         self.assert_sql_count(testing.db, go, 0)
 
         def go():
-            s.query(User).get(10)  # expire flag reset, so not expired
+            s.get(User, 10)  # expire flag reset, so not expired
 
         self.assert_sql_count(testing.db, go, 0)
 
     def test_get_on_deleted_expunges(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session(autocommit=False)
-        u = s.query(User).get(10)
+        u = s.get(User, 10)
 
         s.expire_all()
         s.execute(users.delete().where(User.id == 10))
 
         # object is gone, get() returns None, removes u from session
         assert u in s
-        assert s.query(User).get(10) is None
+        assert s.get(User, 10) is None
         assert u not in s  # and expunges
 
     def test_refresh_on_deleted_raises(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session(autocommit=False)
-        u = s.query(User).get(10)
+        u = s.get(User, 10)
         s.expire_all()
 
         s.expire_all()
@@ -179,14 +182,14 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_rollback_undoes_expunge_from_deleted(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session(autocommit=False)
-        u = s.query(User).get(10)
+        u = s.get(User, 10)
         s.expire_all()
         s.execute(users.delete().where(User.id == 10))
 
         # do a get()/remove u from session
-        assert s.query(User).get(10) is None
+        assert s.get(User, 10) is None
         assert u not in s
 
         s.rollback()
@@ -202,7 +205,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
         Order, orders = self.classes.Order, self.tables.orders
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             Order,
             orders,
             properties={"description": deferred(orders.c.description)},
@@ -234,9 +237,11 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_deferred_notfound(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users, properties={"name": deferred(users.c.name)})
+        self.mapper_registry.map_imperatively(
+            User, users, properties={"name": deferred(users.c.name)}
+        )
         s = fixture_session(autocommit=False)
-        u = s.query(User).get(10)
+        u = s.get(User, 10)
 
         assert "name" not in u.__dict__
         s.execute(users.delete().where(User.id == 10))
@@ -257,7 +262,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -266,9 +271,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         s = fixture_session(autoflush=True, autocommit=False)
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         adlist = u.addresses
         eq_(
             adlist,
@@ -301,7 +306,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -310,9 +315,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         s = fixture_session(autoflush=True, autocommit=False)
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         assert_raises_message(
             sa_exc.InvalidRequestError,
             "properties specified for refresh",
@@ -324,14 +329,14 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_refresh_cancels_expire(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session()
-        u = s.query(User).get(7)
+        u = s.get(User, 7)
         s.expire(u)
         s.refresh(u)
 
         def go():
-            u = s.query(User).get(7)
+            u = s.get(User, 7)
             eq_(u.name, "jack")
 
         self.assert_sql_count(testing.db, go, 0)
@@ -339,10 +344,10 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_expire_doesntload_on_set(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u, attribute_names=["name"])
 
@@ -352,14 +357,14 @@ class ExpireTest(_fixtures.FixtureTest):
         self.assert_sql_count(testing.db, go, 0)
         sess.flush()
         sess.expunge_all()
-        assert sess.query(User).get(7).name == "somenewname"
+        assert sess.get(User, 7).name == "somenewname"
 
     def test_no_session(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u, attribute_names=["name"])
         sess.expunge(u)
@@ -370,7 +375,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
         # this was the opposite in 0.4, but the reasoning there seemed off.
         # expiring a pending instance makes no sense, so should raise
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
         u = User(id=15)
         sess.add(u)
@@ -383,9 +388,9 @@ class ExpireTest(_fixtures.FixtureTest):
         # an instance is pending, but has expired attributes.  this
         # is actually part of a larger behavior when postfetch needs to
         # occur during a flush() on an instance that was just inserted
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u, attribute_names=["name"])
         sess.expunge(u)
@@ -399,9 +404,9 @@ class ExpireTest(_fixtures.FixtureTest):
 
         # same as test_no_instance_key, but the PK columns
         # are absent.  ensure an error is raised.
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u, attribute_names=["name", "id"])
         sess.expunge(u)
@@ -416,9 +421,9 @@ class ExpireTest(_fixtures.FixtureTest):
 
         Order, orders = self.classes.Order, self.tables.orders
 
-        mapper(Order, orders)
+        self.mapper_registry.map_imperatively(Order, orders)
         sess = fixture_session(autoflush=False)
-        o = sess.query(Order).get(3)
+        o = sess.get(Order, 3)
         sess.expire(o)
 
         o.description = "order 3 modified"
@@ -467,10 +472,10 @@ class ExpireTest(_fixtures.FixtureTest):
 
         orders, Order = self.tables.orders, self.classes.Order
 
-        mapper(Order, orders)
+        self.mapper_registry.map_imperatively(Order, orders)
 
         sess = fixture_session(autoflush=False)
-        o = sess.query(Order).get(3)
+        o = sess.get(Order, 3)
         sess.expire(o)
 
         sess.execute(orders.update(), dict(description="order 3 modified"))
@@ -493,7 +498,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -502,9 +507,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         s = fixture_session(autoflush=False)
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         assert u.addresses[0].email_address == "ed@wood.com"
 
         u.addresses[0].email_address = "someotheraddress"
@@ -519,7 +524,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -528,9 +533,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         s = fixture_session(autoflush=False)
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         assert u.addresses[0].email_address == "ed@wood.com"
 
         u.addresses[0].email_address = "someotheraddress"
@@ -561,15 +566,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, cascade=cascade)},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         s = fixture_session(autoflush=False)
 
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         a = Address(id=12, email_address="foobar")
 
         u.addresses.append(a)
@@ -593,15 +598,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session()
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u)
         assert "name" not in u.__dict__
@@ -624,7 +629,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -633,10 +638,10 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session()
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         sess.expire(u)
         assert "name" not in u.__dict__
@@ -673,7 +678,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -682,10 +687,10 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
 
         a1 = u.addresses[0]
         eq_(a1.email_address, "jack@bean.com")
@@ -718,13 +723,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"orders": relationship(Order, order_by=orders.c.id)},
         )
-        mapper(Address, addresses, properties={"user": relationship(User)})
-        mapper(Order, orders)
+        self.mapper_registry.map_imperatively(
+            Address, addresses, properties={"user": relationship(User)}
+        )
+        self.mapper_registry.map_imperatively(Order, orders)
 
         sess = fixture_session(autoflush=False)
 
@@ -819,7 +826,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -828,9 +835,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
         sess.expire(u, ["name", "addresses"])
         u.addresses
         assert "name" not in u.__dict__
@@ -849,7 +856,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
         # changed in #1763, eager loaders are run when we unexpire
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -858,9 +865,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         sess = fixture_session()
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
         sess.expire(u)
         u.id
 
@@ -878,14 +885,14 @@ class ExpireTest(_fixtures.FixtureTest):
 
         # changed in #1763, eager loaders are run when we unexpire
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         sess = fixture_session()
-        u = sess.query(User).options(joinedload(User.addresses)).get(8)
+        u = sess.get(User, 8, options=[joinedload(User.addresses)])
         sess.expire(u)
         u.id
         assert "addresses" in u.__dict__
@@ -899,7 +906,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.tables.addresses,
             self.classes.User,
         )
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -908,9 +915,9 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
         sess = fixture_session()
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
         sess.expire(u)
 
         # here, the lazy loader will encounter the attribute already
@@ -926,17 +933,19 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_expire_synonym(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users, properties={"uname": sa.orm.synonym("name")})
+        self.mapper_registry.map_imperatively(
+            User, users, properties={"uname": sa.orm.synonym("name")}
+        )
 
         sess = fixture_session()
-        u = sess.query(User).get(7)
+        u = sess.get(User, 7)
         assert "name" in u.__dict__
         assert u.uname == u.name
 
         sess.expire(u)
         assert "name" not in u.__dict__
 
-        sess.execute(users.update(users.c.id == 7), dict(name="jack2"))
+        sess.execute(users.update().where(users.c.id == 7), dict(name="jack2"))
         assert u.name == "jack2"
         assert u.uname == "jack2"
         assert "name" in u.__dict__
@@ -950,10 +959,10 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_partial_expire(self):
         orders, Order = self.tables.orders, self.classes.Order
 
-        mapper(Order, orders)
+        self.mapper_registry.map_imperatively(Order, orders)
 
         sess = fixture_session(autoflush=False)
-        o = sess.query(Order).get(3)
+        o = sess.get(Order, 3)
 
         sess.expire(o, attribute_names=["description"])
         assert "id" in o.__dict__
@@ -961,7 +970,7 @@ class ExpireTest(_fixtures.FixtureTest):
         assert attributes.instance_state(o).dict["isopen"] == 1
 
         sess.execute(
-            orders.update(orders.c.id == 3),
+            orders.update().where(orders.c.id == 3),
             dict(description="order 3 modified"),
         )
 
@@ -1014,15 +1023,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
 
         sess.expire(u, ["name", "addresses"])
         assert "name" not in u.__dict__
@@ -1072,7 +1081,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -1081,10 +1090,10 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
 
         sess.expire(u, ["name", "addresses"])
         assert "name" not in u.__dict__
@@ -1130,15 +1139,15 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
         assert "name" in u.__dict__
         u.addresses
         assert "addresses" in u.__dict__
@@ -1148,7 +1157,7 @@ class ExpireTest(_fixtures.FixtureTest):
         assert "addresses" not in u.__dict__
         (
             sess.query(User)
-            .options(sa.orm.joinedload("addresses"))
+            .options(sa.orm.joinedload(User.addresses))
             .filter_by(id=8)
             .all()
         )
@@ -1158,14 +1167,14 @@ class ExpireTest(_fixtures.FixtureTest):
     def test_partial_expire_deferred(self):
         orders, Order = self.tables.orders, self.classes.Order
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             Order,
             orders,
             properties={"description": sa.orm.deferred(orders.c.description)},
         )
 
         sess = fixture_session(autoflush=False)
-        o = sess.query(Order).get(3)
+        o = sess.get(Order, 3)
         sess.expire(o, ["description", "isopen"])
         assert "isopen" not in o.__dict__
         assert "description" not in o.__dict__
@@ -1193,11 +1202,11 @@ class ExpireTest(_fixtures.FixtureTest):
 
         sa.orm.clear_mappers()
 
-        mapper(Order, orders)
+        self.mapper_registry.map_imperatively(Order, orders)
         sess.expunge_all()
 
         # same tests, using deferred at the options level
-        o = sess.query(Order).options(sa.orm.defer("description")).get(3)
+        o = sess.get(Order, 3, options=[sa.orm.defer(Order.description)])
 
         assert "description" not in o.__dict__
 
@@ -1241,7 +1250,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -1250,10 +1259,10 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
-        u = sess.query(User).get(8)
+        u = sess.get(User, 8)
         assert len(u.addresses) == 3
         sess.expire(u)
         assert "addresses" not in u.__dict__
@@ -1270,7 +1279,7 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -1282,7 +1291,7 @@ class ExpireTest(_fixtures.FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
         userlist = sess.query(User).order_by(User.id).all()
@@ -1304,7 +1313,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session(autoflush=False)
 
@@ -1354,7 +1363,9 @@ class ExpireTest(_fixtures.FixtureTest):
 
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users, properties={"name": deferred(users.c.name)})
+        self.mapper_registry.map_imperatively(
+            User, users, properties={"name": deferred(users.c.name)}
+        )
 
         sess = fixture_session(autoflush=False)
         u1 = sess.query(User).options(undefer(User.name)).first()
@@ -1403,12 +1414,12 @@ class ExpireTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, lazy="noload")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         sess = fixture_session(autoflush=False)
         u1 = sess.query(User).options(lazyload(User.addresses)).first()
@@ -1450,7 +1461,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
     def test_deferred_expire_w_transient_to_detached(self):
         orders, Order = self.tables.orders, self.classes.Order
-        mapper(
+        self.mapper_registry.map_imperatively(
             Order,
             orders,
             properties={"description": deferred(orders.c.description)},
@@ -1466,7 +1477,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
     def test_deferred_expire_normally(self):
         orders, Order = self.tables.orders, self.classes.Order
-        mapper(
+        self.mapper_registry.map_imperatively(
             Order,
             orders,
             properties={"description": deferred(orders.c.description)},
@@ -1481,7 +1492,7 @@ class ExpireTest(_fixtures.FixtureTest):
 
     def test_deferred_expire_explicit_attrs(self):
         orders, Order = self.tables.orders, self.classes.Order
-        mapper(
+        self.mapper_registry.map_imperatively(
             Order,
             orders,
             properties={"description": deferred(orders.c.description)},
@@ -1563,13 +1574,13 @@ class PolymorphicExpireTest(fixtures.MappedTest):
             cls.classes.Engineer,
         )
 
-        mapper(
+        cls.mapper_registry.map_imperatively(
             Person,
             people,
             polymorphic_on=people.c.type,
             polymorphic_identity="person",
         )
-        mapper(
+        cls.mapper_registry.map_imperatively(
             Engineer,
             engineers,
             inherits=Person,
@@ -1626,7 +1637,7 @@ class PolymorphicExpireTest(fixtures.MappedTest):
         Engineer = self.classes.Engineer
 
         sess = fixture_session(autoflush=False)
-        e1 = sess.query(Engineer).get(2)
+        e1 = sess.get(Engineer, 2)
 
         sess.expire(e1, attribute_names=["name"])
         sess.expunge(e1)
@@ -1641,7 +1652,7 @@ class PolymorphicExpireTest(fixtures.MappedTest):
         # same as test_no_instance_key, but the PK columns
         # are absent.  ensure an error is raised.
         sess = fixture_session(autoflush=False)
-        e1 = sess.query(Engineer).get(2)
+        e1 = sess.get(Engineer, 2)
 
         sess.expire(e1, attribute_names=["name", "person_id"])
         sess.expunge(e1)
@@ -1665,14 +1676,14 @@ class ExpiredPendingTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={"addresses": relationship(Address, backref="user")},
         )
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
-        sess = fixture_session(autoflush=False)
+        sess = fixture_session(autoflush=False, future=True)
         a1 = Address(email_address="a1")
         sess.add(a1)
         sess.flush()
@@ -1690,6 +1701,9 @@ class ExpiredPendingTest(_fixtures.FixtureTest):
         a2 = Address(email_address="a2")
         a2.user = u1
 
+        # needed now that cascade backrefs is disabled
+        sess.add(a2)
+
         # expire u1.addresses again.  this expires
         # "pending" as well.
         sess.expire(u1, ["addresses"])
@@ -1749,9 +1763,11 @@ class LifecycleTest(fixtures.MappedTest):
 
     @classmethod
     def setup_mappers(cls):
-        mapper(cls.classes.Data, cls.tables.data)
-        mapper(cls.classes.DataFetched, cls.tables.data_fetched)
-        mapper(
+        cls.mapper_registry.map_imperatively(cls.classes.Data, cls.tables.data)
+        cls.mapper_registry.map_imperatively(
+            cls.classes.DataFetched, cls.tables.data_fetched
+        )
+        cls.mapper_registry.map_imperatively(
             cls.classes.DataDefer,
             cls.tables.data_defer,
             properties={"data": deferred(cls.tables.data_defer.c.data)},
@@ -1863,17 +1879,18 @@ class RefreshTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
                 "addresses": relationship(
-                    mapper(Address, addresses), backref="user"
+                    self.mapper_registry.map_imperatively(Address, addresses),
+                    backref="user",
                 )
             },
         )
         s = fixture_session(autoflush=False)
-        u = s.query(User).get(7)
+        u = s.get(User, 7)
         u.name = "foo"
         a = Address()
         assert sa.orm.object_session(a) is None
@@ -1906,9 +1923,9 @@ class RefreshTest(_fixtures.FixtureTest):
     def test_persistence_check(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session()
-        u = s.query(User).get(7)
+        u = s.get(User, 7)
         s.expunge_all()
         assert_raises_message(
             sa_exc.InvalidRequestError,
@@ -1920,13 +1937,15 @@ class RefreshTest(_fixtures.FixtureTest):
         User, users = self.classes.User, self.tables.users
         Address, addresses = self.classes.Address, self.tables.addresses
 
-        mapper(User, users)
-        mapper(Address, addresses, properties={"user": relationship(User)})
+        self.mapper_registry.map_imperatively(User, users)
+        self.mapper_registry.map_imperatively(
+            Address, addresses, properties={"user": relationship(User)}
+        )
 
         s = fixture_session()
 
-        a1 = s.query(Address).get(2)
-        u1 = s.query(User).get(7)
+        a1 = s.get(Address, 2)
+        u1 = s.get(User, 7)
         a1.user = u1
 
         s.refresh(a1, ["user_id"])
@@ -1937,9 +1956,9 @@ class RefreshTest(_fixtures.FixtureTest):
     def test_refresh_expired(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = fixture_session()
-        u = s.query(User).get(7)
+        u = s.get(User, 7)
         s.expire(u)
         assert "name" not in u.__dict__
         s.refresh(u)
@@ -1958,12 +1977,16 @@ class RefreshTest(_fixtures.FixtureTest):
         )
 
         s = fixture_session()
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
-            properties={"addresses": relationship(mapper(Address, addresses))},
+            properties={
+                "addresses": relationship(
+                    self.mapper_registry.map_imperatively(Address, addresses)
+                )
+            },
         )
-        q = s.query(User).options(sa.orm.lazyload("addresses"))
+        q = s.query(User).options(sa.orm.lazyload(User.addresses))
         u = q.filter(users.c.id == 8).first()
 
         def go():
@@ -1982,24 +2005,25 @@ class RefreshTest(_fixtures.FixtureTest):
             self.classes.User,
         )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties={
                 "addresses": relationship(
-                    mapper(Address, addresses), lazy="joined"
+                    self.mapper_registry.map_imperatively(Address, addresses),
+                    lazy="joined",
                 )
             },
         )
 
         s = fixture_session()
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         assert len(u.addresses) == 3
         s.refresh(u)
         assert len(u.addresses) == 3
 
         s = fixture_session()
-        u = s.query(User).get(8)
+        u = s.get(User, 8)
         assert len(u.addresses) == 3
         s.expire(u)
         assert len(u.addresses) == 3
@@ -2012,21 +2036,25 @@ class RefreshTest(_fixtures.FixtureTest):
             "users", "addresses", "dingalings"
         )
 
-        mapper(User, users, properties={"addresses": relationship(Address)})
+        self.mapper_registry.map_imperatively(
+            User, users, properties={"addresses": relationship(Address)}
+        )
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             Address,
             addresses,
             properties={"dingalings": relationship(Dingaling)},
         )
 
-        mapper(Dingaling, dingalings)
+        self.mapper_registry.map_imperatively(Dingaling, dingalings)
 
         s = fixture_session()
         q = (
             s.query(User)
             .filter_by(name="fred")
-            .options(sa.orm.lazyload("addresses").joinedload("dingalings"))
+            .options(
+                sa.orm.lazyload(User.addresses).joinedload(Address.dingalings)
+            )
         )
 
         u1 = q.one()
@@ -2061,9 +2089,9 @@ class RefreshTest(_fixtures.FixtureTest):
         )
 
         s = fixture_session()
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
-        mapper(
+        self.mapper_registry.map_imperatively(
             User,
             users,
             properties=dict(
