@@ -14,8 +14,8 @@ from sqlalchemy import testing
 from sqlalchemy import text
 from sqlalchemy.future import Engine
 from sqlalchemy.orm import attributes
+from sqlalchemy.orm import clear_mappers
 from sqlalchemy.orm import exc as orm_exc
-from sqlalchemy.orm import mapper
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm import Session
 from sqlalchemy.orm import session as _session
@@ -58,7 +58,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         User, users = self.classes.User, self.tables.users
 
         c = conn
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         s = Session(bind=c)
         s.begin()
         tran = s._legacy_transaction()
@@ -74,26 +74,10 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         assert s._legacy_transaction() is tran
         tran.close()
 
-    def test_subtransaction_on_external_subtrans(self, conn):
-        users, User = self.tables.users, self.classes.User
-
-        mapper(User, users)
-
-        trans = conn.begin()
-        sess = Session(bind=conn, autocommit=False, autoflush=True)
-        sess.begin(subtransactions=True)
-        u = User(name="ed")
-        sess.add(u)
-        sess.flush()
-        sess.commit()  # commit does nothing
-        trans.rollback()  # rolls back
-        assert len(sess.query(User).all()) == 0
-        sess.close()
-
     def test_subtransaction_on_external_no_begin(self, conn):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         trans = conn.begin()
         sess = Session(bind=conn, autocommit=False, autoflush=True)
         u = User(name="ed")
@@ -108,7 +92,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_external_nested_transaction(self, conn):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         trans = conn.begin()
         sess = Session(bind=conn, autocommit=False, autoflush=True)
         u1 = User(name="u1")
@@ -127,7 +111,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_subtransaction_on_external_commit_future(self, future_conn):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         conn = future_conn
         conn.begin()
@@ -144,7 +128,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_subtransaction_on_external_rollback_future(self, future_conn):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         conn = future_conn
         conn.begin()
@@ -162,7 +146,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_savepoint_on_external_future(self, future_conn):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         conn = future_conn
         conn.begin()
@@ -184,7 +168,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_nested_accounting_new_items_removed(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         session = fixture_session()
         session.begin()
@@ -200,7 +184,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_nested_accounting_deleted_items_restored(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         session = fixture_session()
         session.begin()
@@ -218,76 +202,11 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         session.rollback()
         assert u1 in session
 
-    @testing.requires.savepoints
-    def test_heavy_nesting(self):
-        users = self.tables.users
-
-        session = fixture_session()
-        session.begin()
-        session.connection().execute(users.insert().values(name="user1"))
-        session.begin(subtransactions=True)
-        session.begin_nested()
-        session.connection().execute(users.insert().values(name="user2"))
-        assert (
-            session.connection()
-            .exec_driver_sql("select count(1) from users")
-            .scalar()
-            == 2
-        )
-        session.rollback()
-        assert (
-            session.connection()
-            .exec_driver_sql("select count(1) from users")
-            .scalar()
-            == 1
-        )
-        session.connection().execute(users.insert().values(name="user3"))
-        session.commit()
-        assert (
-            session.connection()
-            .exec_driver_sql("select count(1) from users")
-            .scalar()
-            == 2
-        )
-
-    @testing.requires.savepoints
-    def test_heavy_nesting_future(self):
-        users = self.tables.users
-
-        engine = Engine._future_facade(testing.db)
-        with Session(engine, autocommit=False) as session:
-            session.begin()
-            session.connection().execute(users.insert().values(name="user1"))
-            session.begin(subtransactions=True)
-            session.begin_nested()
-            session.connection().execute(users.insert().values(name="user2"))
-            assert (
-                session.connection()
-                .exec_driver_sql("select count(1) from users")
-                .scalar()
-                == 2
-            )
-            session.rollback()
-            assert (
-                session.connection()
-                .exec_driver_sql("select count(1) from users")
-                .scalar()
-                == 1
-            )
-            session.connection().execute(users.insert().values(name="user3"))
-            session.commit()
-            assert (
-                session.connection()
-                .exec_driver_sql("select count(1) from users")
-                .scalar()
-                == 2
-            )
-
     @testing.requires.savepoints
     def test_dirty_state_transferred_deep_nesting(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         with fixture_session() as s:
             u1 = User(name="u1")
@@ -315,7 +234,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_dirty_state_transferred_deep_nesting_future(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         with fixture_session(future=True) as s:
             u1 = User(name="u1")
@@ -343,7 +262,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_transactions_isolated(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         s1 = fixture_session(autocommit=False)
         s2 = fixture_session(autocommit=False)
@@ -364,11 +283,11 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
 
         # TODO: mock up a failure condition here
         # to ensure a rollback succeeds
-        mapper(User, users)
-        mapper(Address, addresses)
+        self.mapper_registry.map_imperatively(User, users)
+        self.mapper_registry.map_imperatively(Address, addresses)
 
         engine2 = engines.testing_engine()
-        sess = fixture_session(autocommit=True, autoflush=False, twophase=True)
+        sess = fixture_session(autoflush=False, twophase=True)
         sess.bind_mapper(User, testing.db)
         sess.bind_mapper(Address, engine2)
         sess.begin()
@@ -385,7 +304,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     @testing.requires.independent_connections
     def test_invalidate(self):
         User, users = self.classes.User, self.tables.users
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
         u = User(name="u1")
         sess.add(u)
@@ -411,25 +330,11 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         assert not c2.invalidated
         assert c2.connection.is_valid
 
-    def test_subtransaction_on_noautocommit(self):
-        User, users = self.classes.User, self.tables.users
-
-        mapper(User, users)
-        sess = fixture_session(autocommit=False, autoflush=True)
-        sess.begin(subtransactions=True)
-        u = User(name="u1")
-        sess.add(u)
-        sess.flush()
-        sess.commit()  # commit does nothing
-        sess.rollback()  # rolls back
-        assert len(sess.query(User).all()) == 0
-        sess.close()
-
     @testing.requires.savepoints
     def test_nested_transaction(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
         sess.begin()
 
@@ -453,7 +358,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_nested_autotrans(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session(autocommit=False)
         u = User(name="u1")
         sess.add(u)
@@ -475,7 +380,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_nested_autotrans_future(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session(autocommit=False, future=True)
         u = User(name="u1")
         sess.add(u)
@@ -497,9 +402,9 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_nested_transaction_connection_add(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
-        sess = fixture_session(autocommit=True)
+        sess = fixture_session()
 
         sess.begin()
         sess.begin_nested()
@@ -516,6 +421,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         sess.commit()
 
         eq_(set(sess.query(User).all()), set([u2]))
+        sess.rollback()
 
         sess.begin()
         sess.begin_nested()
@@ -529,43 +435,11 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
 
         sess.close()
 
-    @testing.requires.savepoints
-    def test_mixed_transaction_control(self):
-        users, User = self.tables.users, self.classes.User
-
-        mapper(User, users)
-
-        sess = fixture_session(autocommit=True)
-
-        sess.begin()
-        sess.begin_nested()
-        transaction = sess.begin(subtransactions=True)
-
-        sess.add(User(name="u1"))
-
-        transaction.commit()
-        sess.commit()
-        sess.commit()
-
-        sess.close()
-
-        eq_(len(sess.query(User).all()), 1)
-
-        t1 = sess.begin()
-        t2 = sess.begin_nested()
-
-        sess.add(User(name="u2"))
-
-        t2.commit()
-        assert sess._legacy_transaction() is t1
-
-        sess.close()
-
     @testing.requires.savepoints
     def test_mixed_transaction_close(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session(autocommit=False)
 
@@ -644,7 +518,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         we're in commit()"""
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
 
         to_flush = [User(name="ed"), User(name="jack"), User(name="wendy")]
@@ -668,7 +542,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_continue_flushing_guard(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
 
         @event.listens_for(sess, "after_flush_postexec")
@@ -682,26 +556,6 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
             sess.commit,
         )
 
-    def test_error_on_using_inactive_session_commands(self):
-        users, User = self.tables.users, self.classes.User
-
-        mapper(User, users)
-        sess = fixture_session(autocommit=True)
-        sess.begin()
-        sess.begin(subtransactions=True)
-        sess.add(User(name="u1"))
-        sess.flush()
-        sess.rollback()
-        assert_raises_message(
-            sa_exc.InvalidRequestError,
-            "This session is in 'inactive' state, due to the SQL transaction "
-            "being rolled back; no further SQL can be emitted within this "
-            "transaction.",
-            sess.begin,
-            subtransactions=True,
-        )
-        sess.close()
-
     def test_no_sql_during_commit(self):
         sess = fixture_session(autocommit=False)
 
@@ -752,7 +606,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
         # test #4050
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         session = Session(bind=testing.db)
 
         rollback_error = testing.db.dialect.dbapi.InterfaceError(
@@ -836,40 +690,10 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
             trans.commit,
         )
 
-    def test_deactive_status_check(self):
-        sess = fixture_session()
-        trans = sess.begin()
-        trans2 = sess.begin(subtransactions=True)
-        trans2.rollback()
-        assert_raises_message(
-            sa_exc.InvalidRequestError,
-            "This session is in 'inactive' state, due to the SQL transaction "
-            "being rolled back; no further SQL can be emitted within this "
-            "transaction.",
-            trans.commit,
-        )
-
-    def test_deactive_status_check_w_exception(self):
-        sess = fixture_session()
-        trans = sess.begin()
-        trans2 = sess.begin(subtransactions=True)
-        try:
-            raise Exception("test")
-        except Exception:
-            trans2.rollback(_capture_exception=True)
-        assert_raises_message(
-            sa_exc.PendingRollbackError,
-            r"This Session's transaction has been rolled back due to a "
-            r"previous exception during flush. To begin a new transaction "
-            r"with this Session, first issue Session.rollback\(\). "
-            r"Original exception was: test",
-            trans.commit,
-        )
-
     def _inactive_flushed_session_fixture(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
         u1 = User(id=1, name="u1")
         sess.add(u1)
@@ -975,7 +799,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_warning_on_using_inactive_session_rollback_evt(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         sess = fixture_session()
         u1 = User(id=1, name="u1")
         sess.add(u1)
@@ -1018,7 +842,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_no_autocommit_with_explicit_commit(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         session = fixture_session(autocommit=False)
         session.add(User(name="ed"))
         session._legacy_transaction().commit()
@@ -1028,7 +852,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_no_autocommit_with_explicit_commit_future(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         session = fixture_session(autocommit=False, future=True)
         session.add(User(name="ed"))
         session._legacy_transaction().commit()
@@ -1041,7 +865,7 @@ class SessionTransactionTest(fixtures.RemovesEvents, FixtureTest):
     def test_report_primary_error_when_rollback_fails(self):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         with fixture_session() as session:
 
@@ -1072,7 +896,7 @@ class _LocalFixture(FixtureTest):
     def setup_mappers(cls):
         User, Address = cls.classes.User, cls.classes.Address
         users, addresses = cls.tables.users, cls.tables.addresses
-        mapper(
+        cls.mapper_registry.map_imperatively(
             User,
             users,
             properties={
@@ -1084,7 +908,7 @@ class _LocalFixture(FixtureTest):
                 )
             },
         )
-        mapper(Address, addresses)
+        cls.mapper_registry.map_imperatively(Address, addresses)
 
 
 def subtransaction_recipe_one(self):
@@ -1207,7 +1031,7 @@ class SubtransactionRecipeTest(FixtureTest):
     ):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         with testing.db.connect() as conn:
             trans = conn.begin()
             sess = Session(conn, future=self.future)
@@ -1224,7 +1048,7 @@ class SubtransactionRecipeTest(FixtureTest):
     def test_recipe_commit_one(self, subtransaction_recipe):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         with fixture_session(future=self.future) as sess:
             with subtransaction_recipe(sess):
                 u = User(name="u1")
@@ -1237,7 +1061,7 @@ class SubtransactionRecipeTest(FixtureTest):
     ):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         with fixture_session(future=self.future) as sess:
             sess.begin()
             with subtransaction_recipe(sess):
@@ -1252,7 +1076,7 @@ class SubtransactionRecipeTest(FixtureTest):
     def test_recipe_mixed_transaction_control(self, subtransaction_recipe):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         with fixture_session(future=self.future) as sess:
 
@@ -1282,7 +1106,7 @@ class SubtransactionRecipeTest(FixtureTest):
     ):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
         with fixture_session(future=self.future) as sess:
             sess.begin()
 
@@ -1341,7 +1165,7 @@ class FixtureDataTest(_LocalFixture):
     def test_attrs_on_rollback(self):
         User = self.classes.User
         sess = fixture_session()
-        u1 = sess.query(User).get(7)
+        u1 = sess.get(User, 7)
         u1.name = "ed"
         sess.rollback()
         eq_(u1.name, "jack")
@@ -1349,7 +1173,7 @@ class FixtureDataTest(_LocalFixture):
     def test_commit_persistent(self):
         User = self.classes.User
         sess = fixture_session()
-        u1 = sess.query(User).get(7)
+        u1 = sess.get(User, 7)
         u1.name = "ed"
         sess.flush()
         sess.commit()
@@ -1358,12 +1182,12 @@ class FixtureDataTest(_LocalFixture):
     def test_concurrent_commit_persistent(self):
         User = self.classes.User
         s1 = fixture_session()
-        u1 = s1.query(User).get(7)
+        u1 = s1.get(User, 7)
         u1.name = "ed"
         s1.commit()
 
         s2 = fixture_session()
-        u2 = s2.query(User).get(7)
+        u2 = s2.get(User, 7)
         assert u2.name == "ed"
         u2.name = "will"
         s2.commit()
@@ -1384,7 +1208,7 @@ class CleanSavepointTest(FixtureTest):
     def _run_test(self, update_fn, future=False):
         User, users = self.classes.User, self.tables.users
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         with fixture_session(future=future) as s:
             u1 = User(name="u1")
@@ -1945,110 +1769,15 @@ class AccountingFlagsTest(_LocalFixture):
         sess.add(u1)
         sess.commit()
 
-        sess.execute(users.update(users.c.name == "ed").values(name="edward"))
+        sess.execute(
+            users.update().where(users.c.name == "ed").values(name="edward")
+        )
 
         assert u1.name == "ed"
         sess.expire_all()
         assert u1.name == "edward"
 
 
-class AutoCommitTest(_LocalFixture):
-    __backend__ = True
-
-    def test_begin_nested_requires_trans(self):
-        sess = fixture_session(autocommit=True)
-        assert_raises(sa_exc.InvalidRequestError, sess.begin_nested)
-
-    def test_begin_preflush(self):
-        User = self.classes.User
-        sess = fixture_session(autocommit=True)
-
-        u1 = User(name="ed")
-        sess.add(u1)
-
-        sess.begin()
-        u2 = User(name="some other user")
-        sess.add(u2)
-        sess.rollback()
-        assert u2 not in sess
-        assert u1 in sess
-        assert sess.query(User).filter_by(name="ed").one() is u1
-
-    def test_accounting_commit_fails_add(self):
-        User = self.classes.User
-        sess = fixture_session(autocommit=True)
-
-        fail = False
-
-        def fail_fn(*arg, **kw):
-            if fail:
-                raise Exception("commit fails")
-
-        event.listen(sess, "after_flush_postexec", fail_fn)
-        u1 = User(name="ed")
-        sess.add(u1)
-
-        fail = True
-        assert_raises(Exception, sess.flush)
-        fail = False
-
-        assert u1 not in sess
-        u1new = User(id=2, name="fred")
-        sess.add(u1new)
-        sess.add(u1)
-        sess.flush()
-        assert u1 in sess
-        eq_(
-            sess.query(User.name).order_by(User.name).all(),
-            [("ed",), ("fred",)],
-        )
-
-    def test_accounting_commit_fails_delete(self):
-        User = self.classes.User
-        sess = fixture_session(autocommit=True)
-
-        fail = False
-
-        def fail_fn(*arg, **kw):
-            if fail:
-                raise Exception("commit fails")
-
-        event.listen(sess, "after_flush_postexec", fail_fn)
-        u1 = User(name="ed")
-        sess.add(u1)
-        sess.flush()
-
-        sess.delete(u1)
-        fail = True
-        assert_raises(Exception, sess.flush)
-        fail = False
-
-        assert u1 in sess
-        assert u1 not in sess.deleted
-        sess.delete(u1)
-        sess.flush()
-        assert u1 not in sess
-        eq_(sess.query(User.name).order_by(User.name).all(), [])
-
-    @testing.requires.updateable_autoincrement_pks
-    def test_accounting_no_select_needed(self):
-        """test that flush accounting works on non-expired instances
-        when autocommit=True/expire_on_commit=True."""
-
-        User = self.classes.User
-        sess = fixture_session(autocommit=True, expire_on_commit=True)
-
-        u1 = User(id=1, name="ed")
-        sess.add(u1)
-        sess.flush()
-
-        u1.id = 3
-        u1.name = "fred"
-        self.assert_sql_count(testing.db, sess.flush, 1)
-        assert "id" not in u1.__dict__
-        eq_(u1.id, 3)
-
-
 class ContextManagerPlusFutureTest(FixtureTest):
     run_inserts = None
     __backend__ = True
@@ -2058,7 +1787,7 @@ class ContextManagerPlusFutureTest(FixtureTest):
     def test_contextmanager_nested_rollback(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session()
 
@@ -2078,7 +1807,7 @@ class ContextManagerPlusFutureTest(FixtureTest):
     def test_contextmanager_commit(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session()
         with sess.begin():
@@ -2090,7 +1819,7 @@ class ContextManagerPlusFutureTest(FixtureTest):
     def test_contextmanager_rollback(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         sess = fixture_session()
 
@@ -2433,7 +2162,7 @@ class ContextManagerPlusFutureTest(FixtureTest):
     ):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         session = fixture_session(
             future=future, expire_on_commit=expire_on_commit
@@ -2591,7 +2320,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
     def test_rollback_recover(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         session = fixture_session()
 
@@ -2620,7 +2349,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
         """test issue #3677"""
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         u1 = User(name="u1")
 
@@ -2643,7 +2372,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
     def test_key_replaced_by_update(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         u1 = User(name="u1")
         u2 = User(name="u2")
@@ -2671,7 +2400,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
     def test_key_replaced_by_update_nested(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         u1 = User(name="u1")
 
@@ -2698,7 +2427,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
     def test_multiple_key_replaced_by_update(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         u1 = User(name="u1")
         u2 = User(name="u2")
@@ -2731,7 +2460,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
     def test_key_replaced_by_oob_insert(self):
         users, User = self.tables.users, self.classes.User
 
-        mapper(User, users)
+        self.mapper_registry.map_imperatively(User, users)
 
         u1 = User(name="u1")
 
@@ -2743,7 +2472,7 @@ class NaturalPKRollbackTest(fixtures.MappedTest):
         s.flush()
 
         s.execute(users.insert().values(name="u1"))
-        u2 = s.query(User).get("u1")
+        u2 = s.get(User, "u1")
 
         assert u1 not in s
         s.rollback()
@@ -2783,7 +2512,7 @@ class JoinIntoAnExternalTransactionFixture(object):
 
         self.connection.close()
 
-    def test_something(self):
+    def test_something(self, connection):
         A = self.A
 
         a1 = A()
@@ -2814,7 +2543,8 @@ class NewStyleJoinIntoAnExternalTransactionTest(
         class A(object):
             pass
 
-        mapper(A, self.table)
+        clear_mappers()
+        self.mapper_registry.map_imperatively(A, self.table)
         self.A = A
 
         # bind an individual Session to the connection
@@ -2872,21 +2602,21 @@ class NewStyleJoinIntoAnExternalTransactionTest(
 class FutureJoinIntoAnExternalTransactionTest(
     NewStyleJoinIntoAnExternalTransactionTest,
     fixtures.FutureEngineMixin,
-    fixtures.TestBase,
+    fixtures.MappedTest,
 ):
     pass
 
 
 class NonFutureJoinIntoAnExternalTransactionTest(
     NewStyleJoinIntoAnExternalTransactionTest,
-    fixtures.TestBase,
+    fixtures.MappedTest,
 ):
     pass
 
 
 class LegacyJoinIntoAnExternalTransactionTest(
     JoinIntoAnExternalTransactionFixture,
-    fixtures.TestBase,
+    fixtures.MappedTest,
 ):
     def setup_session(self):
         # begin a non-ORM transaction
@@ -2895,7 +2625,9 @@ class LegacyJoinIntoAnExternalTransactionTest(
         class A(object):
             pass
 
-        mapper(A, self.table)
+        # TODO: py2 is not hitting this correctly for some reason,
+        # some mro issue
+        self.mapper_registry.map_imperatively(A, self.table)
         self.A = A
 
         # bind an individual Session to the connection
@@ -2936,7 +2668,7 @@ class LegacyBranchedJoinIntoAnExternalTransactionTest(
         class A(object):
             pass
 
-        mapper(A, self.table)
+        self.mapper_registry.map_imperatively(A, self.table)
         self.A = A
 
         # neutron is doing this inside of a migration
