@@ -17,6 +17,7 @@ from sqlalchemy.sql import roles
 from sqlalchemy.sql import select
 from sqlalchemy.sql import table
 from sqlalchemy.sql import util as sql_util
+from sqlalchemy.sql.traversals import HasCacheKey
 from sqlalchemy.testing import assert_raises_message
 from sqlalchemy.testing import AssertsCompiledSQL
 from sqlalchemy.testing import eq_
@@ -25,6 +26,7 @@ from sqlalchemy.testing import is_
 from sqlalchemy.testing import ne_
 from sqlalchemy.testing.assertions import expect_raises_message
 from sqlalchemy.testing.assertsql import CompiledSQL
+from sqlalchemy.types import ARRAY
 from sqlalchemy.types import Boolean
 from sqlalchemy.types import Integer
 from sqlalchemy.types import String
@@ -150,7 +152,7 @@ class LambdaElementTest(
             asserter_.assert_(
                 CompiledSQL(
                     "SELECT users.id FROM users WHERE users.name "
-                    "IN ([POSTCOMPILE_val_1]) ORDER BY users.id",
+                    "IN (__[POSTCOMPILE_val_1]) ORDER BY users.id",
                     params={"val_1": case},
                 )
             )
@@ -897,6 +899,42 @@ class LambdaElementTest(
             checkparams={"q_1": 1},
         )
 
+    def test_offline_cache_key_no_paramtrack(self):
+        def go():
+            stmt = lambdas.lambda_stmt(
+                lambda: select(column("x")).where(
+                    column("y") == bindparam("q")
+                ),
+                global_track_bound_values=False,
+            )
+
+            return stmt
+
+        s1 = go()
+
+        eq_(
+            s1._generate_cache_key().to_offline_string({}, s1, {"q": 5}),
+            "('SELECT x \\nWHERE y = :q', (5,))",
+        )
+
+    def test_offline_cache_key_paramtrack(self):
+        def go(param):
+            stmt = lambdas.lambda_stmt(
+                lambda: select(column("x")).where(column("y") == param),
+            )
+
+            return stmt
+
+        s1 = go(5)
+
+        param_key = s1._resolved._where_criteria[0].right.key
+        eq_(
+            s1._generate_cache_key().to_offline_string(
+                {}, s1, {param_key: 10}
+            ),
+            "('SELECT x \\nWHERE y = :param_1', (10,))",
+        )
+
     def test_stmt_lambda_w_list_of_opts(self):
         def go(opts):
             stmt = lambdas.lambda_stmt(lambda: select(column("x")))
@@ -917,6 +955,63 @@ class LambdaElementTest(
         eq_(s1key.key, s2key.key)
         ne_(s1key.key, s3key.key)
 
+    def test_stmt_lambda_opt_w_key(self):
+        """test issue related to #6887"""
+
+        def go(opts):
+            stmt = lambdas.lambda_stmt(lambda: select(column("x")))
+            stmt += lambda stmt: stmt.options(*opts)
+
+            return stmt
+
+        class SomeOpt(HasCacheKey):
+            def _gen_cache_key(self, anon_map, bindparams):
+                return ("fixed_key",)
+
+        # generates no key, will not be cached
+        eq_(SomeOpt()._generate_cache_key().key, ("fixed_key",))
+
+        s1o, s2o = SomeOpt(), SomeOpt()
+        s1 = go([s1o])
+        s2 = go([s2o])
+
+        s1key = s1._generate_cache_key()
+        s2key = s2._generate_cache_key()
+
+        eq_(s1key.key[-1], (("fixed_key",),))
+        eq_(s1key.key, s2key.key)
+
+        eq_(s1._resolved._with_options, (s1o,))
+        eq_(s2._resolved._with_options, (s1o,))
+        ne_(s2._resolved._with_options, (s2o,))
+
+    def test_stmt_lambda_opt_w_no_key(self):
+        """test issue related to #6887"""
+
+        def go(opts):
+            stmt = lambdas.lambda_stmt(lambda: select(column("x")))
+            stmt += lambda stmt: stmt.options(*opts)
+
+            return stmt
+
+        class SomeOpt(HasCacheKey):
+            pass
+
+        # generates no key, will not be cached
+        eq_(SomeOpt()._generate_cache_key(), None)
+
+        s1o, s2o = SomeOpt(), SomeOpt()
+        s1 = go([s1o])
+        s2 = go([s2o])
+
+        s1key = s1._generate_cache_key()
+
+        eq_(s1key, None)
+
+        eq_(s1._resolved._with_options, (s1o,))
+        eq_(s2._resolved._with_options, (s2o,))
+        ne_(s2._resolved._with_options, (s1o,))
+
     def test_stmt_lambda_hey_theres_multiple_paths(self):
         def go(x, y):
             stmt = lambdas.lambda_stmt(lambda: select(column("x")))
@@ -1035,7 +1130,7 @@ class LambdaElementTest(
     def test_in_parameters_one(self):
 
         expr1 = select(1).where(column("q").in_(["a", "b", "c"]))
-        self.assert_compile(expr1, "SELECT 1 WHERE q IN ([POSTCOMPILE_q_1])")
+        self.assert_compile(expr1, "SELECT 1 WHERE q IN (__[POSTCOMPILE_q_1])")
 
         self.assert_compile(
             expr1,
@@ -1046,7 +1141,7 @@ class LambdaElementTest(
 
     def test_in_parameters_two(self):
         expr2 = select(1).where(lambda: column("q").in_(["a", "b", "c"]))
-        self.assert_compile(expr2, "SELECT 1 WHERE q IN ([POSTCOMPILE_q_1])")
+        self.assert_compile(expr2, "SELECT 1 WHERE q IN (__[POSTCOMPILE_q_1])")
         self.assert_compile(
             expr2,
             "SELECT 1 WHERE q IN (:q_1_1, :q_1_2, :q_1_3)",
@@ -1058,7 +1153,7 @@ class LambdaElementTest(
         expr3 = lambdas.lambda_stmt(
             lambda: select(1).where(column("q").in_(["a", "b", "c"]))
         )
-        self.assert_compile(expr3, "SELECT 1 WHERE q IN ([POSTCOMPILE_q_1])")
+        self.assert_compile(expr3, "SELECT 1 WHERE q IN (__[POSTCOMPILE_q_1])")
         self.assert_compile(
             expr3,
             "SELECT 1 WHERE q IN (:q_1_1, :q_1_2, :q_1_3)",
@@ -1074,7 +1169,7 @@ class LambdaElementTest(
 
         expr4 = go(["a", "b", "c"])
         self.assert_compile(
-            expr4, "SELECT 1 WHERE q IN ([POSTCOMPILE_names_1])"
+            expr4, "SELECT 1 WHERE q IN (__[POSTCOMPILE_names_1])"
         )
         self.assert_compile(
             expr4,
@@ -1086,9 +1181,9 @@ class LambdaElementTest(
     def test_in_parameters_five(self):
         def go(n1, n2):
             stmt = lambdas.lambda_stmt(
-                lambda: select(1).where(column("q").in_(n1))
+                lambda: select(1).where(column("q", ARRAY(String)).in_(n1))
             )
-            stmt += lambda s: s.where(column("y").in_(n2))
+            stmt += lambda s: s.where(column("y", ARRAY(String)).in_(n2))
             return stmt
 
         expr = go(["a", "b", "c"], ["d", "e", "f"])
@@ -1726,7 +1821,7 @@ class DeferredLambdaElementTest(
             opts=lambdas.LambdaOptions(track_closure_variables=False),
         )
 
-        self.assert_compile(elem.expr, "t1.q IN ([POSTCOMPILE_vv_1])")
+        self.assert_compile(elem.expr, "t1.q IN (__[POSTCOMPILE_vv_1])")
 
         assert_raises_message(
             exc.InvalidRequestError,
